==> core-react-0.8.0.tgz: package/es/Form/FormInput/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Input from '../../Input';

var FormInput = function FormInput(props, context) {
  var children = props.children,
      className = props.className,
      onChange = props.onChange,
      other = _objectWithoutProperties(props, ["children", "className", "onChange"]);

  var form = context.form,
      formItem = context.formItem;
  other.value = form.getItemValue(formItem);

  other.onChange = function (value) {
    form.setItemValue(formItem, value);
    onChange && onChange(value);
  };

  return React.createElement(Input, _extends({
    className: cx("".concat("waui", "-form__input"), className)
  }, other));
};

FormInput.propTypes = {
  onChange: PropTypes.func,
  children: PropTypes.node,
  className: PropTypes.string
};
FormInput.contextTypes = {
  form: PropTypes.object.isRequired,
  formItem: PropTypes.object.isRequired
};
export default FormInput;

==> core-react-0.8.2.tgz: package/es/Form/FormInput/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Input from '../../Input';

var FormInput = function FormInput(props, context) {
  var children = props.children,
      className = props.className,
      onChange = props.onChange,
      other = _objectWithoutProperties(props, ["children", "className", "onChange"]);

  var form = context.form,
      formItem = context.formItem;
  other.value = form.getItemValue(formItem);

  other.onChange = function (value) {
    form.setItemValue(formItem, value);
    onChange && onChange(value);
  };

  return (/*#__PURE__*/React.createElement(Input, _extends({
      className: cx("".concat("waui", "-form__input"), className)
    }, other))
  );
};

FormInput.propTypes = {
  onChange: PropTypes.func,
  children: PropTypes.node,
  className: PropTypes.string
};
FormInput.contextTypes = {
  form: PropTypes.object.isRequired,
  formItem: PropTypes.object.isRequired
};
export default FormInput;
